@@ -440,8 +440,8 @@ class PreseemNetworkMetadataModel(object):
             for obj in mods:
                 await dst_model.set_nm(obj)
 
-        await asyncio.wait([self.update(), dst_model.update()])
-        await asyncio.wait([copy_refs(), copy_nms()])
+        await asyncio.gather(self.update(), dst_model.update())
+        await asyncio.gather(copy_refs(), copy_nms())
 
     def diff(self, rhs_model):
         """Compare this model to another one."""
