@@ -8,6 +8,13 @@ from preseem_protobuf.network_poller import network_poller_pb2
 # TODO
 # check optional values on Get and return None if not presenet.
 
+class NetworkElementUpdateException(Exception):
+    """Allows a poll operation to raise an error for the NetworkElement."""
+    def __init__(self, error, msg):
+        self.error = error
+        super().__init__(msg)
+
+
 class ErrorContext:
     """Container for holding errors during protobuf operations."""
     Error = namedtuple('Error', ('code', 'msg', 'args'))
@@ -1525,4 +1532,4 @@ class NetworkElementDiscovery:
     @status.setter
     def status(self, value):
         if value is not None:
-            self.pb.status = value
\ No newline at end of file
+            self.pb.status = value
